@@ -22,7 +22,7 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 # POSSIBILITY OF SUCH DAMAGE.
 package Graphics::GVG::AST;
-$Graphics::GVG::AST::VERSION = '0.6';
+$Graphics::GVG::AST::VERSION = '0.7';
 use strict;
 use warnings;
 use Moose;
@@ -40,6 +40,13 @@ has 'commands' => (
     },
 );
 
+has 'meta_data' => (
+    is => 'ro',
+    isa => 'HashRef[Str]',
+    default => sub {{}},
+    writer => '_set_meta_data',
+);
+
 
 sub to_string
 {
@@ -84,6 +91,11 @@ AST. Note that the output may not be exactly what you input, as certain
 compile time transforms will loose information. The two should be semantically 
 identical, however.
 
+=head2 meta_data
+
+Returns the hashref of metadata associated with this AST. This is only set 
+on the root element of the AST.
+
 =head1 COMMANDS
 
 These all do the role C<Graphics::GVG::AST::Command>, which in turn does the 
